@@ -432,7 +432,11 @@ class AuthProxy:
         host = listen_config.get("host", "127.0.0.1")
         port = listen_config.get("port")
         socket_path = listen_config.get("socket")
-        socket_mode = listen_config.get("socket_chmod")
+        socket_mode = (
+            int(str(listen_config["socket-chmod"]), 8)
+            if "socket-chmod" in listen_config
+            else None
+        )
 
         if socket_path:
             # Unix socket server
